/* c-irrlicht --- C bindings for Irrlicht Engine

   Copyright (C) 2019 Javier Sancho <jsf@jsancho.org>

   This file is part of c-irrlicht.

   c-irrlicht is free software; you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as
   published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   c-irrlicht is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with guile-irrlicht.  If not, see
   <http://www.gnu.org/licenses/>.
*/

#include <irrlicht/irrlicht.h>
#include "IVideoDriver.h"

extern "C" {
  bool irr_video_IVideoDriver_beginScene(void* driver,
                                         bool backBuffer,
                                         bool zBuffer,
                                         const irr_video_SColor* color,
                                         void* videoData, // not used for now
                                         const irr_core_rect_s32* sourceRect)
  {
    // Color
    irr::video::SColor col = irr::video::SColor(color->a, color->r,
                                                color->g, color->b);

    // Video data
    irr::video::SExposedVideoData vdata = irr::video::SExposedVideoData();

    // Source rect
    irr::core::rect<irr::s32> rect =            \
      irr::core::rect<irr::s32>(sourceRect->x,
                                sourceRect->y,
                                sourceRect->x2,
                                sourceRect->y2);

    // Begin scene
    return ((irr::video::IVideoDriver*)driver)->beginScene(backBuffer,
                                                          zBuffer,
                                                          col,
                                                          vdata,
                                                          &rect);
  }

  bool irr_videoIVideoDriver_endScene(void* driver)
  {
    return ((irr::video::IVideoDriver*)driver)->endScene();
  }
}
